# svreg : regression based on Shapley Values.

----

## Installation

Svreg is now on the Python Index.
To install the package:

```bash
pip install svreg
```

## Requirements

See requirements.txt

## Example

Please have a look at the notebook basic_example.ipynb for indications on how to use this package.

## Changelog

- 0.1.0: Initial release
